@@ -8,14 +8,17 @@ class Setup():
 
     #rute = path.abspath(path.join(''))
     rute0 = site.getsitepackages()
+    rute = rute0[0]
+
+
     print("The library is installed in")
     print(rute + '/KrakenOS')
     print("for help see Examples directory")
     print("To change glass catalog modify catalog list in SetupCas.py")
     print("See User_Manual USER_MANUAL_KrakenOS_Provisional.pdf in:" )
-    print(print(rute + '/Docs))
+    print(print(rute + '/Docs'))
+
 
-    rute = rute0[0]
     ## Add catalog you need
     cat1 = (rute + '/KrakenOS/Cat/SCHOTT.AGF')
     cat2 = (rute + '/KrakenOS/Cat/TSPM.AGF')
